@@ -3,6 +3,7 @@
 
 """
 ===============================================================================
+
     Copyright (C) 2009-2018 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
@@ -18,6 +19,7 @@
     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     See the License for the specific language governing permissions and
     limitations under the License.
+
 ===============================================================================
 """
 
@@ -28,7 +30,13 @@ def modelrepr(instance) -> str:
     """Default repr version of a Django model object, for debugging."""
     elements = []
     # noinspection PyProtectedMember
-    for fieldname in [f.name for f in instance._meta.get_fields()]:
+    for f in instance._meta.get_fields():
+        # https://docs.djangoproject.com/en/2.0/ref/models/meta/
+        if f.auto_created:
+            continue
+        if f.is_relation and f.related_model is None:
+            continue
+        fieldname = f.name
         try:
             value = repr(getattr(instance, fieldname))
         except ObjectDoesNotExist:
