@@ -23,7 +23,7 @@
 ===============================================================================
 """
 
-VERSION = '1.0.19'
+VERSION = '1.0.20'
 # Use semantic versioning: http://semver.org/
 
 RECENT_VERSION_HISTORY = r"""
@@ -96,7 +96,7 @@ First started in 2009.
   - update for Django 2.0+
   - update for Pendulum 2.0+
   
-- 1.0.19, 2018-07-01
+- 1.0.19 to 1.0.20, 2018-07-01
   - psychiatry/drugs.py
 
 """
